uparma-py - the Python framework for the uparma project
=======================================================

*UPARMA - Universal Parameter Mapper for Proteomics*

|build-status-travis| |doc-status| |build-status-appveyor|

.. |build-status-travis| image:: https://travis-ci.org/uparma/uparma-py.svg?branch=master
   :target: https://travis-ci.org/uparma/uparma-py
   :alt: Travis CI status

.. |doc-status| image:: http://readthedocs.org/projects/parma-py/badge/?version=latest
   :target: http://parma-py.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status
   
.. |build-status-appveyor| image:: https://ci.appveyor.com/api/projects/status/uig935fvjxnn6xmf?svg=true
   :target: https://ci.appveyor.com/project/fufezan-lab/uparma-py
   :alt: AppVeyor CI status

Installation
############

Use pip to install, use virtualenv for maximum convenience::

    user@localhost$ pip install -r requirements


Testing
#######

Use pytest to run tests::

    user@localhost$ pytest
